"""
backend_statistic_chart automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass, field
from dataclasses_json import dataclass_json, config
from typing import List
from .backend_statistic_chart_data import BackendStatisticChartData
@dataclass_json
@dataclass
class BackendStatisticChart:
    labels: List[str] = field(default=None, metadata=config(field_name="labels"))
    data: List[BackendStatisticChartData] = field(default=None, metadata=config(field_name="data"))
    series: List[str] = field(default=None, metadata=config(field_name="series"))



"""
backend_marketplace_remote_app automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass, field
from dataclasses_json import dataclass_json, config
from .backend_marketplace_app import BackendMarketplaceApp
@dataclass_json
@dataclass
class BackendMarketplaceRemoteApp(BackendMarketplaceApp):
    local: BackendMarketplaceApp = field(default=None, metadata=config(field_name="local"))



"""
consumer_grant automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass, field
from dataclasses_json import dataclass_json, config
import datetime
from .consumer_app import ConsumerApp
@dataclass_json
@dataclass
class ConsumerGrant:
    id: int = field(default=None, metadata=config(field_name="id"))
    app: ConsumerApp = field(default=None, metadata=config(field_name="app"))
    create_date: datetime.datetime = field(default=None, metadata=config(field_name="createDate"))



"""
consumer_app automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass, field
from dataclasses_json import dataclass_json, config
from typing import List
from .common_metadata import CommonMetadata
@dataclass_json
@dataclass
class ConsumerApp:
    id: int = field(default=None, metadata=config(field_name="id"))
    user_id: int = field(default=None, metadata=config(field_name="userId"))
    status: int = field(default=None, metadata=config(field_name="status"))
    name: str = field(default=None, metadata=config(field_name="name"))
    url: str = field(default=None, metadata=config(field_name="url"))
    app_key: str = field(default=None, metadata=config(field_name="appKey"))
    app_secret: str = field(default=None, metadata=config(field_name="appSecret"))
    date: str = field(default=None, metadata=config(field_name="date"))
    scopes: List[str] = field(default=None, metadata=config(field_name="scopes"))
    metadata: CommonMetadata = field(default=None, metadata=config(field_name="metadata"))



"""
system_o_auth_configuration automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass, field
from dataclasses_json import dataclass_json, config
from typing import List
@dataclass_json
@dataclass
class SystemOAuthConfiguration:
    issuer: str = field(default=None, metadata=config(field_name="issuer"))
    token_endpoint: str = field(default=None, metadata=config(field_name="token_endpoint"))
    token_endpoint_auth_methods_supported: List[str] = field(default=None, metadata=config(field_name="token_endpoint_auth_methods_supported"))
    userinfo_endpoint: str = field(default=None, metadata=config(field_name="userinfo_endpoint"))
    scopes_supported: List[str] = field(default=None, metadata=config(field_name="scopes_supported"))
    claims_supported: List[str] = field(default=None, metadata=config(field_name="claims_supported"))



"""
backend_identity_index_entry automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass, field
from dataclasses_json import dataclass_json, config
@dataclass_json
@dataclass
class BackendIdentityIndexEntry:
    name: str = field(default=None, metadata=config(field_name="name"))
    _class: str = field(default=None, metadata=config(field_name="class"))



"""
common_message automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass, field
from dataclasses_json import dataclass_json, config
@dataclass_json
@dataclass
class CommonMessage:
    success: bool = field(default=None, metadata=config(field_name="success"))
    message: str = field(default=None, metadata=config(field_name="message"))
    id: str = field(default=None, metadata=config(field_name="id"))



"""
backend_webhook automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass, field
from dataclasses_json import dataclass_json, config
from typing import List
from .backend_webhook_response import BackendWebhookResponse
@dataclass_json
@dataclass
class BackendWebhook:
    id: int = field(default=None, metadata=config(field_name="id"))
    event_id: int = field(default=None, metadata=config(field_name="eventId"))
    user_id: int = field(default=None, metadata=config(field_name="userId"))
    name: str = field(default=None, metadata=config(field_name="name"))
    endpoint: str = field(default=None, metadata=config(field_name="endpoint"))
    responses: List[BackendWebhookResponse] = field(default=None, metadata=config(field_name="responses"))



"""
backend_cronjob automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass, field
from dataclasses_json import dataclass_json, config
from typing import List
import datetime
from .common_metadata import CommonMetadata
from .backend_cronjob_error import BackendCronjobError
@dataclass_json
@dataclass
class BackendCronjob:
    id: int = field(default=None, metadata=config(field_name="id"))
    name: str = field(default=None, metadata=config(field_name="name"))
    cron: str = field(default=None, metadata=config(field_name="cron"))
    action: str = field(default=None, metadata=config(field_name="action"))
    execute_date: datetime.datetime = field(default=None, metadata=config(field_name="executeDate"))
    exit_code: int = field(default=None, metadata=config(field_name="exitCode"))
    metadata: CommonMetadata = field(default=None, metadata=config(field_name="metadata"))
    errors: List[BackendCronjobError] = field(default=None, metadata=config(field_name="errors"))



"""
backend_page_create automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass, field
from dataclasses_json import dataclass_json, config
from .backend_page import BackendPage
@dataclass_json
@dataclass
class BackendPageCreate(BackendPage):



"""
system_route automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass, field
from dataclasses_json import dataclass_json, config
from .system_route_path import SystemRoutePath
@dataclass_json
@dataclass
class SystemRoute:
    routes: SystemRoutePath = field(default=None, metadata=config(field_name="routes"))



"""
backend_dashboard automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass, field
from dataclasses_json import dataclass_json, config
from .backend_statistic_chart import BackendStatisticChart
from .backend_dashboard_apps import BackendDashboardApps
from .backend_dashboard_requests import BackendDashboardRequests
from .backend_dashboard_users import BackendDashboardUsers
from .backend_dashboard_transactions import BackendDashboardTransactions
@dataclass_json
@dataclass
class BackendDashboard:
    errors_per_operation: BackendStatisticChart = field(default=None, metadata=config(field_name="errorsPerOperation"))
    incoming_requests: BackendStatisticChart = field(default=None, metadata=config(field_name="incomingRequests"))
    incoming_transactions: BackendStatisticChart = field(default=None, metadata=config(field_name="incomingTransactions"))
    most_used_operations: BackendStatisticChart = field(default=None, metadata=config(field_name="mostUsedOperations"))
    time_per_operation: BackendStatisticChart = field(default=None, metadata=config(field_name="timePerOperation"))
    latest_apps: BackendDashboardApps = field(default=None, metadata=config(field_name="latestApps"))
    latest_requests: BackendDashboardRequests = field(default=None, metadata=config(field_name="latestRequests"))
    latest_users: BackendDashboardUsers = field(default=None, metadata=config(field_name="latestUsers"))
    latest_transactions: BackendDashboardTransactions = field(default=None, metadata=config(field_name="latestTransactions"))



"""
backend_plan automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass, field
from dataclasses_json import dataclass_json, config
from typing import List
from .common_metadata import CommonMetadata
@dataclass_json
@dataclass
class BackendPlan:
    id: int = field(default=None, metadata=config(field_name="id"))
    name: str = field(default=None, metadata=config(field_name="name"))
    description: str = field(default=None, metadata=config(field_name="description"))
    price: float = field(default=None, metadata=config(field_name="price"))
    points: int = field(default=None, metadata=config(field_name="points"))
    period: int = field(default=None, metadata=config(field_name="period"))
    external_id: str = field(default=None, metadata=config(field_name="externalId"))
    scopes: List[str] = field(default=None, metadata=config(field_name="scopes"))
    metadata: CommonMetadata = field(default=None, metadata=config(field_name="metadata"))



"""
CommonMessageException automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

import sdkgen

from .common_message import CommonMessage

class CommonMessageException(sdkgen.KnownStatusCodeException):
    def __init__(self, payload):
        self.payload = CommonMessage.from_json(payload)

    pass

    def get_payload(self) -> CommonMessage:
        return self.payload

    pass



"""
consumer_user_jwt automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass, field
from dataclasses_json import dataclass_json, config
@dataclass_json
@dataclass
class ConsumerUserJWT:
    token: str = field(default=None, metadata=config(field_name="token"))
    expires_in: int = field(default=None, metadata=config(field_name="expires_in"))
    refresh_token: str = field(default=None, metadata=config(field_name="refresh_token"))
    scope: str = field(default=None, metadata=config(field_name="scope"))



"""
consumer_app_update automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass, field
from dataclasses_json import dataclass_json, config
from typing import List
@dataclass_json
@dataclass
class ConsumerAppUpdate:
    name: str = field(default=None, metadata=config(field_name="name"))
    url: str = field(default=None, metadata=config(field_name="url"))
    scopes: List[str] = field(default=None, metadata=config(field_name="scopes"))



"""
backend_marketplace_collection automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass, field
from dataclasses_json import dataclass_json, config
from .backend_marketplace_collection_apps import BackendMarketplaceCollectionApps
@dataclass_json
@dataclass
class BackendMarketplaceCollection:
    apps: BackendMarketplaceCollectionApps = field(default=None, metadata=config(field_name="apps"))



"""
backend_operation automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass, field
from dataclasses_json import dataclass_json, config
from typing import List
from .backend_operation_parameters import BackendOperationParameters
from .backend_operation_throws import BackendOperationThrows
from .common_metadata import CommonMetadata
@dataclass_json
@dataclass
class BackendOperation:
    id: int = field(default=None, metadata=config(field_name="id"))
    status: int = field(default=None, metadata=config(field_name="status"))
    active: bool = field(default=None, metadata=config(field_name="active"))
    public: bool = field(default=None, metadata=config(field_name="public"))
    stability: int = field(default=None, metadata=config(field_name="stability"))
    description: str = field(default=None, metadata=config(field_name="description"))
    http_method: str = field(default=None, metadata=config(field_name="httpMethod"))
    http_path: str = field(default=None, metadata=config(field_name="httpPath"))
    http_code: int = field(default=None, metadata=config(field_name="httpCode"))
    name: str = field(default=None, metadata=config(field_name="name"))
    parameters: BackendOperationParameters = field(default=None, metadata=config(field_name="parameters"))
    incoming: str = field(default=None, metadata=config(field_name="incoming"))
    outgoing: str = field(default=None, metadata=config(field_name="outgoing"))
    throws: BackendOperationThrows = field(default=None, metadata=config(field_name="throws"))
    action: str = field(default=None, metadata=config(field_name="action"))
    costs: int = field(default=None, metadata=config(field_name="costs"))
    scopes: List[str] = field(default=None, metadata=config(field_name="scopes"))
    metadata: CommonMetadata = field(default=None, metadata=config(field_name="metadata"))



"""
backend_action_execute_response automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass, field
from dataclasses_json import dataclass_json, config
from .backend_action_execute_response_headers import BackendActionExecuteResponseHeaders
from .backend_action_execute_response_body import BackendActionExecuteResponseBody
@dataclass_json
@dataclass
class BackendActionExecuteResponse:
    status_code: int = field(default=None, metadata=config(field_name="statusCode"))
    headers: BackendActionExecuteResponseHeaders = field(default=None, metadata=config(field_name="headers"))
    body: BackendActionExecuteResponseBody = field(default=None, metadata=config(field_name="body"))



"""
backend_scope_categories automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass, field
from dataclasses_json import dataclass_json, config
from typing import List
from .backend_scope_category import BackendScopeCategory
@dataclass_json
@dataclass
class BackendScopeCategories:
    categories: List[BackendScopeCategory] = field(default=None, metadata=config(field_name="categories"))



"""
common_form_element_tag automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass, field
from dataclasses_json import dataclass_json, config
from .common_form_element import CommonFormElement
@dataclass_json
@dataclass
class CommonFormElementTag(CommonFormElement):



"""
backend_identity_index automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass, field
from dataclasses_json import dataclass_json, config
from typing import List
from .backend_identity_index_entry import BackendIdentityIndexEntry
@dataclass_json
@dataclass
class BackendIdentityIndex:
    providers: List[BackendIdentityIndexEntry] = field(default=None, metadata=config(field_name="providers"))



"""
common_form_element automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass, field
from dataclasses_json import dataclass_json, config
@dataclass_json
@dataclass
class CommonFormElement:
    element: str = field(default=None, metadata=config(field_name="element"))
    name: str = field(default=None, metadata=config(field_name="name"))
    title: str = field(default=None, metadata=config(field_name="title"))
    help: str = field(default=None, metadata=config(field_name="help"))



"""
backend_config_update automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass, field
from dataclasses_json import dataclass_json, config
from .backend_config import BackendConfig
@dataclass_json
@dataclass
class BackendConfigUpdate(BackendConfig):



"""
common_collection automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass, field
from dataclasses_json import dataclass_json, config
from typing import List
@dataclass_json
@dataclass
class CommonCollection:
    total_results: int = field(default=None, metadata=config(field_name="totalResults"))
    start_index: int = field(default=None, metadata=config(field_name="startIndex"))
    items_per_page: int = field(default=None, metadata=config(field_name="itemsPerPage"))
    entry: List[T] = field(default=None, metadata=config(field_name="entry"))



"""
backend_action_index automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass, field
from dataclasses_json import dataclass_json, config
from typing import List
from .backend_action_index_entry import BackendActionIndexEntry
@dataclass_json
@dataclass
class BackendActionIndex:
    actions: List[BackendActionIndexEntry] = field(default=None, metadata=config(field_name="actions"))



"""
backend_user_create automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass, field
from dataclasses_json import dataclass_json, config
from .backend_user import BackendUser
@dataclass_json
@dataclass
class BackendUserCreate(BackendUser):
    password: str = field(default=None, metadata=config(field_name="password"))



"""
backend_connection automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass, field
from dataclasses_json import dataclass_json, config
from .backend_connection_config import BackendConnectionConfig
from .common_metadata import CommonMetadata
@dataclass_json
@dataclass
class BackendConnection:
    id: int = field(default=None, metadata=config(field_name="id"))
    name: str = field(default=None, metadata=config(field_name="name"))
    _class: str = field(default=None, metadata=config(field_name="class"))
    config: BackendConnectionConfig = field(default=None, metadata=config(field_name="config"))
    metadata: CommonMetadata = field(default=None, metadata=config(field_name="metadata"))



"""
common_form_element_input automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass, field
from dataclasses_json import dataclass_json, config
from .common_form_element import CommonFormElement
@dataclass_json
@dataclass
class CommonFormElementInput(CommonFormElement):
    type: str = field(default=None, metadata=config(field_name="type"))



"""
backend_webhook_response automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass, field
from dataclasses_json import dataclass_json, config
import datetime
@dataclass_json
@dataclass
class BackendWebhookResponse:
    id: int = field(default=None, metadata=config(field_name="id"))
    status: int = field(default=None, metadata=config(field_name="status"))
    code: int = field(default=None, metadata=config(field_name="code"))
    attempts: int = field(default=None, metadata=config(field_name="attempts"))
    error: str = field(default=None, metadata=config(field_name="error"))
    execute_date: datetime.datetime = field(default=None, metadata=config(field_name="executeDate"))



"""
consumer_payment_portal_request automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass, field
from dataclasses_json import dataclass_json, config
@dataclass_json
@dataclass
class ConsumerPaymentPortalRequest:
    return_url: str = field(default=None, metadata=config(field_name="returnUrl"))



"""
backend_scope_operation automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass, field
from dataclasses_json import dataclass_json, config
@dataclass_json
@dataclass
class BackendScopeOperation:
    operation_id: int = field(default=None, metadata=config(field_name="operationId"))
    allow: bool = field(default=None, metadata=config(field_name="allow"))



"""
backend_scope_category_scope automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass, field
from dataclasses_json import dataclass_json, config
@dataclass_json
@dataclass
class BackendScopeCategoryScope:
    id: int = field(default=None, metadata=config(field_name="id"))
    name: str = field(default=None, metadata=config(field_name="name"))
    description: str = field(default=None, metadata=config(field_name="description"))



"""
backend_rate_allocation automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass, field
from dataclasses_json import dataclass_json, config
@dataclass_json
@dataclass
class BackendRateAllocation:
    id: int = field(default=None, metadata=config(field_name="id"))
    operation_id: int = field(default=None, metadata=config(field_name="operationId"))
    user_id: int = field(default=None, metadata=config(field_name="userId"))
    plan_id: int = field(default=None, metadata=config(field_name="planId"))
    app_id: int = field(default=None, metadata=config(field_name="appId"))
    authenticated: bool = field(default=None, metadata=config(field_name="authenticated"))



"""
backend_config automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass, field
from dataclasses_json import dataclass_json, config
from typing import Any
@dataclass_json
@dataclass
class BackendConfig:
    id: int = field(default=None, metadata=config(field_name="id"))
    type: int = field(default=None, metadata=config(field_name="type"))
    name: str = field(default=None, metadata=config(field_name="name"))
    description: str = field(default=None, metadata=config(field_name="description"))
    value: Any = field(default=None, metadata=config(field_name="value"))



"""
backend_statistic_chart_data automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass, field
from dataclasses_json import dataclass_json, config
from typing import Any
from typing import Dict
class BackendStatisticChartData(Dict[str, Any]):
    pass



"""
BackendBackupTag automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

import requests
import sdkgen
from requests import RequestException

from .backend_backup_export import BackendBackupExport
from .backend_backup_import import BackendBackupImport
from .backend_backup_import_result import BackendBackupImportResult
from .common_message_exception import CommonMessageException

class BackendBackupTag(sdkgen.TagAbstract):
    def __init__(self, http_client: requests.Session, parser: sdkgen.Parser):
        super().__init__(http_client, parser)

    pass


    def _import(self, payload: BackendBackupImport) -> BackendBackupImportResult:
        try:
            path_params = {}

            query_params = {}

            query_struct_names = []

            url = self.parser.url("/backend/backup/import", path_params)

            headers = {}
            headers["Content-Type"] = "application/json"

            response = self.http_client.post(url, headers=headers, params=self.parser.query(query_params, query_struct_names), data=payload.to_json())

            if response.status_code >= 200 and response.status_code < 300:
                return BackendBackupImportResult.from_json(response.content)

            if response.status_code == 401:
                raise CommonMessageException(response.content)
            if response.status_code == 500:
                raise CommonMessageException(response.content)

            raise sdkgen.UnknownStatusCodeException("The server returned an unknown status code")
        except RequestException as e:
            raise sdkgen.ClientException("An unknown error occurred: " + str(e))

    pass

    def export(self) -> BackendBackupExport:
        try:
            path_params = {}

            query_params = {}

            query_struct_names = []

            url = self.parser.url("/backend/backup/export", path_params)

            headers = {}

            response = self.http_client.post(url, headers=headers, params=self.parser.query(query_params, query_struct_names))

            if response.status_code >= 200 and response.status_code < 300:
                return BackendBackupExport.from_json(response.content)

            if response.status_code == 401:
                raise CommonMessageException(response.content)
            if response.status_code == 500:
                raise CommonMessageException(response.content)

            raise sdkgen.UnknownStatusCodeException("The server returned an unknown status code")
        except RequestException as e:
            raise sdkgen.ClientException("An unknown error occurred: " + str(e))

    pass





"""
backend_generator_provider automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass, field
from dataclasses_json import dataclass_json, config
from typing import List
from .backend_generator_provider_config import BackendGeneratorProviderConfig
@dataclass_json
@dataclass
class BackendGeneratorProvider:
    path: str = field(default=None, metadata=config(field_name="path"))
    scopes: List[str] = field(default=None, metadata=config(field_name="scopes"))
    public: bool = field(default=None, metadata=config(field_name="public"))
    config: BackendGeneratorProviderConfig = field(default=None, metadata=config(field_name="config"))



"""
consumer_user_account automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass, field
from dataclasses_json import dataclass_json, config
from typing import List
import datetime
from .consumer_user_plan import ConsumerUserPlan
from .common_metadata import CommonMetadata
@dataclass_json
@dataclass
class ConsumerUserAccount:
    id: int = field(default=None, metadata=config(field_name="id"))
    plan_id: int = field(default=None, metadata=config(field_name="planId"))
    status: int = field(default=None, metadata=config(field_name="status"))
    name: str = field(default=None, metadata=config(field_name="name"))
    email: str = field(default=None, metadata=config(field_name="email"))
    points: int = field(default=None, metadata=config(field_name="points"))
    scopes: List[str] = field(default=None, metadata=config(field_name="scopes"))
    plans: List[ConsumerUserPlan] = field(default=None, metadata=config(field_name="plans"))
    metadata: CommonMetadata = field(default=None, metadata=config(field_name="metadata"))
    date: datetime.datetime = field(default=None, metadata=config(field_name="date"))



"""
consumer_authorize_response automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass, field
from dataclasses_json import dataclass_json, config
from .consumer_authorize_response_token import ConsumerAuthorizeResponseToken
@dataclass_json
@dataclass
class ConsumerAuthorizeResponse:
    type: str = field(default=None, metadata=config(field_name="type"))
    token: ConsumerAuthorizeResponseToken = field(default=None, metadata=config(field_name="token"))
    code: str = field(default=None, metadata=config(field_name="code"))
    redirect_uri: str = field(default=None, metadata=config(field_name="redirectUri"))



"""
backend_audit automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass, field
from dataclasses_json import dataclass_json, config
import datetime
from .backend_app import BackendApp
from .backend_user import BackendUser
from .backend_audit_object import BackendAuditObject
@dataclass_json
@dataclass
class BackendAudit:
    id: int = field(default=None, metadata=config(field_name="id"))
    app: BackendApp = field(default=None, metadata=config(field_name="app"))
    user: BackendUser = field(default=None, metadata=config(field_name="user"))
    event: str = field(default=None, metadata=config(field_name="event"))
    ip: str = field(default=None, metadata=config(field_name="ip"))
    message: str = field(default=None, metadata=config(field_name="message"))
    content: BackendAuditObject = field(default=None, metadata=config(field_name="content"))
    date: datetime.datetime = field(default=None, metadata=config(field_name="date"))



"""
backend_dashboard_requests automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass, field
from dataclasses_json import dataclass_json, config
from .common_collection import CommonCollection
from .backend_dashboard_request import BackendDashboardRequest
@dataclass_json
@dataclass
class BackendDashboardRequests(CommonCollection[BackendDashboardRequest]):
    pass



"""
system_schema automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass, field
from dataclasses_json import dataclass_json, config
from .system_schema_type_schema import SystemSchemaTypeSchema
from .system_schema_form import SystemSchemaForm
@dataclass_json
@dataclass
class SystemSchema:
    schema: SystemSchemaTypeSchema = field(default=None, metadata=config(field_name="schema"))
    form: SystemSchemaForm = field(default=None, metadata=config(field_name="form"))



"""
backend_operation_create automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass, field
from dataclasses_json import dataclass_json, config
from .backend_operation import BackendOperation
@dataclass_json
@dataclass
class BackendOperationCreate(BackendOperation):



"""
common_metadata automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass, field
from dataclasses_json import dataclass_json, config
from typing import Dict
class CommonMetadata(Dict[str, str]):
    pass



"""
backend_generator_provider_changelog automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass, field
from dataclasses_json import dataclass_json, config
from typing import List
from .backend_schema import BackendSchema
from .backend_action import BackendAction
from .backend_operation import BackendOperation
@dataclass_json
@dataclass
class BackendGeneratorProviderChangelog:
    schemas: List[BackendSchema] = field(default=None, metadata=config(field_name="schemas"))
    actions: List[BackendAction] = field(default=None, metadata=config(field_name="actions"))
    operations: List[BackendOperation] = field(default=None, metadata=config(field_name="operations"))



"""
backend_action_execute_request automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass, field
from dataclasses_json import dataclass_json, config
from .backend_action_execute_request_body import BackendActionExecuteRequestBody
@dataclass_json
@dataclass
class BackendActionExecuteRequest:
    method: str = field(default=None, metadata=config(field_name="method"))
    uri_fragments: str = field(default=None, metadata=config(field_name="uriFragments"))
    parameters: str = field(default=None, metadata=config(field_name="parameters"))
    headers: str = field(default=None, metadata=config(field_name="headers"))
    body: BackendActionExecuteRequestBody = field(default=None, metadata=config(field_name="body"))



"""
backend_dashboard_transaction automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass, field
from dataclasses_json import dataclass_json, config
import datetime
@dataclass_json
@dataclass
class BackendDashboardTransaction:
    id: int = field(default=None, metadata=config(field_name="id"))
    status: str = field(default=None, metadata=config(field_name="status"))
    provider: str = field(default=None, metadata=config(field_name="provider"))
    transaction_id: str = field(default=None, metadata=config(field_name="transactionId"))
    amount: float = field(default=None, metadata=config(field_name="amount"))
    date: datetime.datetime = field(default=None, metadata=config(field_name="date"))



"""
backend_cronjob_collection automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass, field
from dataclasses_json import dataclass_json, config
from .common_collection import CommonCollection
from .backend_cronjob import BackendCronjob
@dataclass_json
@dataclass
class BackendCronjobCollection(CommonCollection[BackendCronjob]):
    pass



"""
backend_log_error automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass, field
from dataclasses_json import dataclass_json, config
@dataclass_json
@dataclass
class BackendLogError:
    id: int = field(default=None, metadata=config(field_name="id"))
    message: int = field(default=None, metadata=config(field_name="message"))
    trace: str = field(default=None, metadata=config(field_name="trace"))
    file: str = field(default=None, metadata=config(field_name="file"))
    line: int = field(default=None, metadata=config(field_name="line"))



"""
backend_identity automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass, field
from dataclasses_json import dataclass_json, config
from .backend_identity_config import BackendIdentityConfig
@dataclass_json
@dataclass
class BackendIdentity:
    id: int = field(default=None, metadata=config(field_name="id"))
    app_id: int = field(default=None, metadata=config(field_name="appId"))
    role_id: int = field(default=None, metadata=config(field_name="roleId"))
    name: str = field(default=None, metadata=config(field_name="name"))
    icon: str = field(default=None, metadata=config(field_name="icon"))
    _class: str = field(default=None, metadata=config(field_name="class"))
    config: BackendIdentityConfig = field(default=None, metadata=config(field_name="config"))
    allow_create: bool = field(default=None, metadata=config(field_name="allowCreate"))



"""
consumer_authorize_request automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass, field
from dataclasses_json import dataclass_json, config
@dataclass_json
@dataclass
class ConsumerAuthorizeRequest:
    response_type: str = field(default=None, metadata=config(field_name="responseType"))
    client_id: str = field(default=None, metadata=config(field_name="clientId"))
    redirect_uri: str = field(default=None, metadata=config(field_name="redirectUri"))
    scope: str = field(default=None, metadata=config(field_name="scope"))
    state: str = field(default=None, metadata=config(field_name="state"))
    allow: bool = field(default=None, metadata=config(field_name="allow"))



"""
backend_backup_import_result automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass, field
from dataclasses_json import dataclass_json, config
from typing import List
@dataclass_json
@dataclass
class BackendBackupImportResult:
    success: bool = field(default=None, metadata=config(field_name="success"))
    message: str = field(default=None, metadata=config(field_name="message"))
    logs: List[str] = field(default=None, metadata=config(field_name="logs"))



"""
backend_connection_introspection_entity automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass, field
from dataclasses_json import dataclass_json, config
from typing import List
from .backend_connection_introspection_entity_row import BackendConnectionIntrospectionEntityRow
@dataclass_json
@dataclass
class BackendConnectionIntrospectionEntity:
    name: str = field(default=None, metadata=config(field_name="name"))
    headers: List[str] = field(default=None, metadata=config(field_name="headers"))
    rows: List[BackendConnectionIntrospectionEntityRow] = field(default=None, metadata=config(field_name="rows"))



"""
consumer_webhook automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass, field
from dataclasses_json import dataclass_json, config
from typing import List
from .consumer_webhook_response import ConsumerWebhookResponse
@dataclass_json
@dataclass
class ConsumerWebhook:
    id: int = field(default=None, metadata=config(field_name="id"))
    status: int = field(default=None, metadata=config(field_name="status"))
    event: str = field(default=None, metadata=config(field_name="event"))
    name: str = field(default=None, metadata=config(field_name="name"))
    endpoint: str = field(default=None, metadata=config(field_name="endpoint"))
    responses: List[ConsumerWebhookResponse] = field(default=None, metadata=config(field_name="responses"))



"""
backend_rate automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass, field
from dataclasses_json import dataclass_json, config
from typing import List
from .backend_rate_allocation import BackendRateAllocation
from .common_metadata import CommonMetadata
@dataclass_json
@dataclass
class BackendRate:
    id: int = field(default=None, metadata=config(field_name="id"))
    priority: int = field(default=None, metadata=config(field_name="priority"))
    name: str = field(default=None, metadata=config(field_name="name"))
    rate_limit: int = field(default=None, metadata=config(field_name="rateLimit"))
    timespan: datetime.timedelta = field(default=None, metadata=config(field_name="timespan"))
    allocation: List[BackendRateAllocation] = field(default=None, metadata=config(field_name="allocation"))
    metadata: CommonMetadata = field(default=None, metadata=config(field_name="metadata"))



"""
consumer_token automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass, field
from dataclasses_json import dataclass_json, config
from typing import List
import datetime
@dataclass_json
@dataclass
class ConsumerToken:
    id: int = field(default=None, metadata=config(field_name="id"))
    status: int = field(default=None, metadata=config(field_name="status"))
    name: str = field(default=None, metadata=config(field_name="name"))
    scopes: List[str] = field(default=None, metadata=config(field_name="scopes"))
    ip: str = field(default=None, metadata=config(field_name="ip"))
    expire: datetime.date = field(default=None, metadata=config(field_name="expire"))
    date: datetime.datetime = field(default=None, metadata=config(field_name="date"))



"""
backend_marketplace_app automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass, field
from dataclasses_json import dataclass_json, config
@dataclass_json
@dataclass
class BackendMarketplaceApp:
    version: str = field(default=None, metadata=config(field_name="version"))
    description: str = field(default=None, metadata=config(field_name="description"))
    screenshot: str = field(default=None, metadata=config(field_name="screenshot"))
    website: str = field(default=None, metadata=config(field_name="website"))
    download_url: str = field(default=None, metadata=config(field_name="downloadUrl"))
    sha_hash: str = field(default=None, metadata=config(field_name="sha1Hash"))
    start_url: str = field(default=None, metadata=config(field_name="startUrl"))



"""
consumer_webhook_response automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass, field
from dataclasses_json import dataclass_json, config
@dataclass_json
@dataclass
class ConsumerWebhookResponse:
    status: int = field(default=None, metadata=config(field_name="status"))
    code: int = field(default=None, metadata=config(field_name="code"))
    attempts: str = field(default=None, metadata=config(field_name="attempts"))
    execute_date: str = field(default=None, metadata=config(field_name="executeDate"))



"""
backend_rate_collection automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass, field
from dataclasses_json import dataclass_json, config
from .common_collection import CommonCollection
from .backend_rate import BackendRate
@dataclass_json
@dataclass
class BackendRateCollection(CommonCollection[BackendRate]):
    pass



"""
backend_operation_schema automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass, field
from dataclasses_json import dataclass_json, config
@dataclass_json
@dataclass
class BackendOperationSchema:
    description: str = field(default=None, metadata=config(field_name="description"))
    type: str = field(default=None, metadata=config(field_name="type"))
    format: str = field(default=None, metadata=config(field_name="format"))
    enum: str = field(default=None, metadata=config(field_name="enum"))



"""
backend_schema automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass, field
from dataclasses_json import dataclass_json, config
from .backend_schema_source import BackendSchemaSource
from .backend_schema_form import BackendSchemaForm
from .common_metadata import CommonMetadata
@dataclass_json
@dataclass
class BackendSchema:
    id: int = field(default=None, metadata=config(field_name="id"))
    status: int = field(default=None, metadata=config(field_name="status"))
    name: str = field(default=None, metadata=config(field_name="name"))
    source: BackendSchemaSource = field(default=None, metadata=config(field_name="source"))
    form: BackendSchemaForm = field(default=None, metadata=config(field_name="form"))
    metadata: CommonMetadata = field(default=None, metadata=config(field_name="metadata"))



"""
backend_statistic_count automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass, field
from dataclasses_json import dataclass_json, config
import datetime
@dataclass_json
@dataclass
class BackendStatisticCount:
    count: int = field(default=None, metadata=config(field_name="count"))
    _from: datetime.datetime = field(default=None, metadata=config(field_name="from"))
    to: datetime.datetime = field(default=None, metadata=config(field_name="to"))



"""
consumer_transaction automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass, field
from dataclasses_json import dataclass_json, config
import datetime
from .consumer_plan import ConsumerPlan
@dataclass_json
@dataclass
class ConsumerTransaction:
    id: int = field(default=None, metadata=config(field_name="id"))
    user_id: int = field(default=None, metadata=config(field_name="userId"))
    plan_id: int = field(default=None, metadata=config(field_name="planId"))
    plan: ConsumerPlan = field(default=None, metadata=config(field_name="plan"))
    transaction_id: str = field(default=None, metadata=config(field_name="transactionId"))
    amount: float = field(default=None, metadata=config(field_name="amount"))
    points: float = field(default=None, metadata=config(field_name="points"))
    period_start: datetime.datetime = field(default=None, metadata=config(field_name="periodStart"))
    period_end: datetime.datetime = field(default=None, metadata=config(field_name="periodEnd"))
    insert_date: datetime.datetime = field(default=None, metadata=config(field_name="insertDate"))



"""
consumer_token_access_token automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass, field
from dataclasses_json import dataclass_json, config
@dataclass_json
@dataclass
class ConsumerTokenAccessToken:
    access_token: str = field(default=None, metadata=config(field_name="access_token"))
    token_type: str = field(default=None, metadata=config(field_name="token_type"))
    expires_in: int = field(default=None, metadata=config(field_name="expires_in"))
    refresh_token: str = field(default=None, metadata=config(field_name="refresh_token"))
    scope: str = field(default=None, metadata=config(field_name="scope"))



"""
consumer_page automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass, field
from dataclasses_json import dataclass_json, config
from .common_metadata import CommonMetadata
@dataclass_json
@dataclass
class ConsumerPage:
    id: int = field(default=None, metadata=config(field_name="id"))
    title: str = field(default=None, metadata=config(field_name="title"))
    slug: str = field(default=None, metadata=config(field_name="slug"))
    content: str = field(default=None, metadata=config(field_name="content"))
    metadata: CommonMetadata = field(default=None, metadata=config(field_name="metadata"))



"""
system_about automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from dataclasses import dataclass, field
from dataclasses_json import dataclass_json, config
from typing import List
from .system_about_apps import SystemAboutApps
from .system_about_link import SystemAboutLink
@dataclass_json
@dataclass
class SystemAbout:
    api_version: str = field(default=None, metadata=config(field_name="apiVersion"))
    title: str = field(default=None, metadata=config(field_name="title"))
    description: str = field(default=None, metadata=config(field_name="description"))
    terms_of_service: str = field(default=None, metadata=config(field_name="termsOfService"))
    contact_name: str = field(default=None, metadata=config(field_name="contactName"))
    contact_url: str = field(default=None, metadata=config(field_name="contactUrl"))
    contact_email: str = field(default=None, metadata=config(field_name="contactEmail"))
    license_name: str = field(default=None, metadata=config(field_name="licenseName"))
    license_url: str = field(default=None, metadata=config(field_name="licenseUrl"))
    payment_currency: str = field(default=None, metadata=config(field_name="paymentCurrency"))
    categories: List[str] = field(default=None, metadata=config(field_name="categories"))
    scopes: List[str] = field(default=None, metadata=config(field_name="scopes"))
    apps: SystemAboutApps = field(default=None, metadata=config(field_name="apps"))
    links: List[SystemAboutLink] = field(default=None, metadata=config(field_name="links"))
